@@ -35,6 +35,8 @@ class CredentialTypes(str, Enum):
     DIAL = "DIAL"
     A2A = "A2A"
     MCP = "MCP"
+    LITE_LLM = "LiteLLM"
+    REPORT_PORTAL = "ReportPortal"
 
 
 class IntegrationType(str, Enum):
